from setuptools import setup

setup(
    name='e-socket',
    version='0.2',
    packages=['e-socket'],
    url='https://github.com/kucer0043/e_socket',
    license='',
    author='kucer0043',
    author_email='kucer0043@gmail.com',
    description='Easy Sockets'
)
